@@ -14,9 +14,13 @@ def config():
 
 
 @config.command()
-def init():
+@click.option('-f', '--force', is_flag=True)
+def init(force):
     if PuddlRC.exists():
-        raise click.ClickException(f'{PuddlRC.PATH} already exists')
+        if not force:
+            raise click.ClickException(f'{PuddlRC.PATH} already exists')
+        else:
+            log.info(f'forcing overwrite of {PuddlRC.PATH}')
     from dotenv import load_dotenv
 
     load_dotenv()
