@@ -22,7 +22,8 @@ def _iter_stdin():
         for bytewurst in f.read().split(b'\n'):
             try:
                 line = bytewurst.decode('utf-8')
-                yield Path(line)
+                if line != '':
+                    yield Path(line)
             except UnicodeDecodeError:
                 log.warning(f'could not decode line {line}')
 
@@ -37,7 +38,8 @@ def index(path):
 
         find . -type f -name '*.py' | puddl file index
     """
-    # Using metavar makes things unnecessarily complicated. We want to keep Backus Naur.
+    # Using click's metavar makes things unnecessarily complicated. We want to keep Backus
+    # Naur in the generated help output.
     paths = path
     del path
 
@@ -52,6 +54,7 @@ def index(path):
     device = get_default_device(session)
     ups = Upserter(session, File)
     for path in _iter_paths():
+        log.debug(path)
         ups.upsert(
             path=path,
             device_id=device.id,
