@@ -36,7 +36,7 @@ def index(path: str, recursive: bool):
             app.df_append(df, 'raw')
             log.info(f'{path} with {len(df)} records')
         except GitLogError as e:
-            log.error(str(e))
+            log.warning(str(e))
 
 
 def main():
